@@ -1,11 +1,6 @@
-"""
-genolearn doc
-
-"""
-
 import os
 
-__version__ = '0.0.9'
+__version__ = '0.1.0'
 
 ls = os.listdir()
 wd = True if '.genolearn' in ls else False
