@@ -4,19 +4,12 @@ import json
 import scipy.sparse
 import numpy  as np
 import gzip
+import warnings
+
+warnings.filterwarnings('ignore')
 
 class DataLoader():
-    """
-    DataLoader Class
 
-    Parameters
-    ----------
-        meta_file   : str
-            Preprocessed metadata within ``preprocess_dir``/meta
-        working_dir : str
-            Path to working directory
-
-    """
     def __init__(self, meta_file, working_dir = working_directory):
         
         if working_dir is None:
@@ -37,10 +30,9 @@ class DataLoader():
         if meta_file not in valid:
             raise Exception(f'"{meta_file}" not found in "{path}" - expect one of' + '\n  •'.join([''] + valid))
 
-        self.dense          = os.path.exists(os.path.join(working_dir, 'preprocess', 'dense'))
         self.working_dir    = working_dir
         self.preprocess_dir = os.path.join(working_dir, 'preprocess')
-        self.data_dir       = os.path.join(self.preprocess_dir, 'dense' if self.dense else 'sparse')
+        self.data_dir       = os.path.join(self.preprocess_dir, 'array')
         
         with open(os.path.join(working_dir, 'meta', meta_file)) as f:
             self.meta = json.load(f)
@@ -50,22 +42,16 @@ class DataLoader():
             info = json.load(f)
             self.n, self.m = info['n'], info['m']
 
-    def _load_X(self, identifier, features):
+    def _load_X(self, identifier, features, dtype):
 
-        npz = os.path.join(self.data_dir, f'{identifier}.npz')
+        npz  = os.path.join(self.data_dir, f'{identifier}.npz')
 
-        if self.dense:
-            arr, = np.load(npz).values()
-        else:
-            arr  = scipy.sparse.load_npz(npz)
+        arr, = np.load(npz).values()
 
         if features is not None:
-            if self.dense:
-                arr = arr[features]
-            else:
-                arr = arr[:,features]
+            arr = arr[features]
         
-        return arr
+        return arr.astype(dtype) if dtype else arr
 
     def _load_Y(self, identifier):
         return self.meta['search'][identifier]
@@ -97,25 +83,13 @@ class DataLoader():
 
         return ret
 
-    def load_X(self, *identifiers, features = None, dtype = np.uint16):
-        r"""
-        loads all observations with associated ``identifiers``. If ``features`` is provided, loads only
-        those feature values. If ``dtype`` is provided, tries to convert the ``dtype`` provided.
-        Returns
-        -------
-            X : numpy.ndarray or scipy.sparse.csr_matrix
-                Defining :math:`n = |\text{identifiers}|`  and :math:`m` as the number of genome
-                sequences identified during the preprocessing stage or :math:`|\text{features}|` if ``features``
-                was provided, then, :math:`X\in\mathbb{Z}^{n,m}`. 
-        """
+    def load_X(self, *identifiers, features = None, dtype = None):
         identifiers = self._check_identifiers(identifiers)
-        m           = self.m if features is None else len(features)
-        if self.dense:
-            X = np.zeros((len(identifiers), m), dtype = dtype)
-            for i, identifier in enumerate(identifiers):
-                X[i] = self._load_X(identifier, features)
-        else:
-            X = scipy.sparse.vstack([self._load(identifier, features) for identifier in identifiers], dtype = dtype)
+        features    = np.array(features)
+        m           = self.m if features is None else features.sum() if features.dtype == np.bool_ else len(features)
+        X           = np.zeros((len(identifiers), m), dtype = dtype)
+        for i, identifier in enumerate(identifiers):
+            X[i] = self._load_X(identifier, features, dtype)
         return X
 
     def load_Y(self, *identifiers):
@@ -127,19 +101,12 @@ class DataLoader():
         identifiers = self._check_identifiers(identifiers)
         return np.array(list(map(self._load_Y, identifiers)))
 
-    def load_train_test_identifiers(self, min_count = 0, target_subset = None):
-        """
-        loads train and test identifiers.
-        Returns
-        -------
-            train_identifiers : numpy.ndarray
-            test_identifiers  : numpy.ndarray
-        """
+    def load_train_val_identifiers(self, min_count = 0, target_subset = None):
         train   = self._check_identifiers(self.meta['Train'])
-        test    = self._check_identifiers(self.meta['Test'])
+        val     = self._check_identifiers(self.meta['Val'])
 
         y_train = self.load_Y(*train)
-        y_test  = self.load_Y(*test)
+        y_val   = self.load_Y(*val)
 
         unique, arg = np.unique(y_train, return_inverse = True)
         dummies     = np.eye(len(unique))[arg]
@@ -153,30 +120,50 @@ class DataLoader():
         self._encoder = {label : i for i, label in enumerate(labels)}
 
         identifiers_train = np.array(train)[np.isin(y_train, labels)]
-        identifiers_test  = np.array(test )[np.isin(y_test , labels)]
+        identifiers_val   = np.array(val  )[np.isin(y_val  , labels)]
 
-        return identifiers_train, identifiers_test
+        return identifiers_train, identifiers_val
 
-    def load_train_test(self, features = None, min_count = 0, target_subset = None, dtype = np.uint16):
-        """
-        using the method ``load_train_test_identifiers`` returns train and test data for supervised learning.
-        Returns
-        -------
-            X_train : load_X(train_identifiers, features = features, sparse = sparse)
-            Y_train : load_Y(train_identifiers)
-            X_test  : load_X(test_identifiers, features = features, sparse = sparse)
-            Y_test  : load_Y(test_identifiers)
-        """
-        self.identifiers_train, self.identifiers_test = self.load_train_test_identifiers(min_count, target_subset)
+    def load_train_val(self, features = None, dtype = None, min_count = 0, target_subset = None):
+        self.identifiers_train, self.identifiers_val = self.load_train_val_identifiers(min_count, target_subset)
 
         Y_train = self.encode(self.load_Y(*self.identifiers_train))
-        Y_test  = self.encode(self.load_Y(*self.identifiers_test ))
+        Y_val   = self.encode(self.load_Y(*self.identifiers_val  ))
 
         X_train = self.load_X(*self.identifiers_train, features = features, dtype = dtype)
-        X_test  = self.load_X(*self.identifiers_test , features = features, dtype = dtype)
+        X_val   = self.load_X(*self.identifiers_val  , features = features, dtype = dtype)
 
-        return X_train, Y_train, X_test, Y_test
+        return X_train, Y_train, X_val, Y_val
     
+    def load_identifiers(self, min_count = 0, target_subset = None):
+        train   = self._check_identifiers(self.meta['Train'] + self.meta['Val'])
+
+        y_train = self.load_Y(*train)
+
+        unique, arg = np.unique(y_train, return_inverse = True)
+        dummies     = np.eye(len(unique))[arg]
+
+        label_counts = dummies.sum(axis = 0)
+        labels       = unique[label_counts >= min_count]
+
+        if target_subset:
+            labels = [label for label in labels if label in target_subset]
+        
+        self._encoder = {label : i for i, label in enumerate(labels)}
+
+        identifiers = np.array(train)[np.isin(y_train, labels)]
+
+        return identifiers
+
+    def load(self, features = None, dtype = None, min_count = 0, target_subset = None):
+
+        self.identifiers = self.load_identifiers(min_count, target_subset)
+
+        Y = self.encode(self.load_Y(*self.identifiers))
+        X = self.load_X(*self.identifiers, features = features, dtype = dtype)
+
+        return X, Y
+
     def encode(self, Y):
         return np.vectorize(lambda value : self._encoder[value])(Y)
 
@@ -194,18 +181,11 @@ class DataLoader():
         ret, = np.load(os.path.join(self.working_dir, 'feature-selection', file), allow_pickle = True).values()
         return ret
 
-    def generator(self, *identifiers, features = None, force_dense = False, force_sparse = False):
+    def generator(self, *identifiers, features = None, dtype = None):
         """
         Iteratively yields an x, y pair from the method ``load``.
         """
         identifiers = self._check_identifiers(identifiers)
 
         for identifier in identifiers:
-            X, Y = self._load_X(identifier, features), self.load_Y(identifier)[0]
-            if force_sparse:
-                if isinstance(X, np.ndarray):
-                    X = scipy.sparse.csr_matrix(X.reshape(1, -1))
-            if force_dense:
-                if not isinstance(X, np.ndarray):
-                    X = X.A.flatten()
-            yield X, Y
\ No newline at end of file
+            yield self._load_X(identifier, features, dtype), self.load_Y(identifier)[0]
